Gammu All Mobile Management Utilities
=====================================

Gammu je knihovna a utilita pro příkazovou řádku pro práci s mobilními
telefont. Je vydáno pod GNU GPL verze 2.

Projekt byl původně veden Marcinem Wiackem. Byl založen na zdrojových kódech
projektů Gnokii <http://www.gnokii.org> a pozdějí MyGnokii
<http://www.mwiacek.com>. Gammu bylo (až do verze 0.58) nazýváno MyGnokii2.

V současné době projekt spravuje Michal Čihař <michal@cihar.com> s pomocí
mnoha přispěvovatelů.

.. image:: https://travis-ci.org/gammu/gammu.svg?branch=master
    :alt: Build status :target: https://travis-ci.org/gammu/gammu

.. image:: https://hosted.weblate.org/widgets/gammu-status-badge.png
    :alt: Translation status :target:
    https://hosted.weblate.org/engage/gammu/?utm_source=widget

.. image:: https://scan.coverity.com/projects/2890/badge.svg?flat=1
    :alt: Coverity scan :target: https://scan.coverity.com/projects/2890

Více informací
==============

Více informací naleznete na <http://cs.wammu.eu/gammu/>.

Další dokumentaci naleznete v Manuálu Gammu, který je v adresáři
docs/manual. Můžete si vytvořit jeho HTML verzi pro prohlížení pomocí make
manual-html, nebo si ji prohlédnout online na
<http://wammu.eu/docs/manual/>.


Zpětná vazba a hlášení chyb
===========================

Jakákoliv zpětná vazba je vítána, informace jak kontaktovat vývojáře
naleznete na <http://cs.wammu.eu/support/>.


Podpořte vývojáře
=================

Práci vývojářů můžete ocenit na <http://cs.wammu.eu/donate/>.
